.. raw:: html

    <style> .red {color:#aa0060; font-weight:bold; font-size:18px} </style>

.. role:: red

.. This documentation was autogenerated using parselglossy. Editing by hand is not recommended.

================
Input parameters
================

- Keywords without a default value are **required**.
- Default values are either explicit or computed from the value of other keywords in the input.
- Sections where all keywords have a default value can be omitted.
- Predicates, if present, are the functions run to validate user input.

:red:`Keywords`
 :title: Title of the calculation. Since there is no default, this keyword is required. 

  **Type** ``str``

:red:`Sections`
 :scf: SCF input parameters. 

  :red:`Keywords`
   :functional: XC functional. We also test that the string contains max 80 characters. 
  
    **Type** ``str``
  
    **Predicates**
      - ``len(value) <= 80``
  
   :max_num_iterations: Max number of iterations. 
  
    **Type** ``int``
  
    **Default** ``20``
  
   :another_number: Testing an even number in some range. 
  
    **Type** ``int``
  
    **Default** ``10``
  
    **Predicates**
      - ``0 <= value <= 40``
      - ``value % 2 == 0``
      - ``user['scf']['some_acceleration'] == True``
  
   :some_acceleration: Turn on the new amazing acceleration scheme. 
  
    **Type** ``bool``
  
    **Default** ``False``
  
   :some_complex_number: Testing input with a complex number. 
  
    **Type** ``complex``
  
    **Default** ``0.0+0.0j``
  
  :red:`Sections`
   :thresholds: Numerical thresholds. 
  
      :red:`Keywords`
       :some_integral_screening: Some integral based threshold. 
      
        **Type** ``float``
      
        **Default** ``0.0001``
      
       :energy: Some energy based threshold. 
      
        **Type** ``float``
      
        **Default** ``0.001``
      